@@ -1,28 +1,42 @@
-import pandas as pd
-from typing import List, Dict, Tuple
+from typing import Collection, List, Tuple
 
+from rexmex.metrics.classification import (
+    accuracy_score,
+    average_precision_score,
+    balanced_accuracy_score,
+    f1_score,
+    fowlkes_mallows_index,
+    matthews_correlation_coefficient,
+    pr_auc_score,
+    precision_score,
+    recall_score,
+    roc_auc_score,
+    specificity,
+)
+from rexmex.metrics.rating import (
+    mean_absolute_error,
+    mean_absolute_percentage_error,
+    mean_squared_error,
+    pearson_correlation_coefficient,
+    r2_score,
+    root_mean_squared_error,
+    symmetric_mean_absolute_percentage_error,
+)
 from rexmex.utils import binarize, normalize
 
-from rexmex.metrics.classification import roc_auc_score
-from rexmex.metrics.classification import accuracy_score, balanced_accuracy_score
-from rexmex.metrics.classification import pr_auc_score, specificity, fowlkes_mallows_index
-from rexmex.metrics.classification import f1_score, precision_score, recall_score, average_precision_score, matthews_correlation_coefficient
-
-from rexmex.metrics.rating import pearson_correlation_coefficient
-from rexmex.metrics.rating import mean_absolute_error, mean_squared_error, mean_absolute_percentage_error, r2_score
-from rexmex.metrics.rating import symmetric_mean_absolute_percentage_error, root_mean_squared_error
 
 class MetricSet(dict):
     """
     A metric set is a special dictionary that contains metric
      name keys and evaluation metric function values.
     """
-    def filter_metrics(self, filter: List[str]=None):
+
+    def filter_metrics(self, filter: Collection[str]):
         """
         A method to keep a list of metrics.
 
         Args:
-            filter (str): A list of metric names to keep.
+            filter: A list of metric names to keep.
         Returns:
             self: The metric set after the metrics were filtered out.
         """
@@ -71,6 +85,7 @@ class MetricSet(dict):
             new_metric_set[name] = metric
         return new_metric_set
 
+
 class ClassificationMetricSet(MetricSet):
     """
     A set of classification metrics with the following metrics included:
@@ -87,6 +102,7 @@ class ClassificationMetricSet(MetricSet):
     | **Accuracy**
     | **Balanced Accuracy**
     """
+
     def __init__(self):
         self["roc_auc"] = roc_auc_score
         self["pr_auc"] = pr_auc_score
@@ -106,18 +122,20 @@ class ClassificationMetricSet(MetricSet):
         """
         return "ClassificationMetricSet()"
 
+
 class RatingMetricSet(MetricSet):
     """
     A set of rating metrics with the following metrics included:
 
-    | **Mean Absolute Error** 
-    | **Mean Squared Error** 
-    | **Root Mean Squared Error** 
+    | **Mean Absolute Error**
+    | **Mean Squared Error**
+    | **Root Mean Squared Error**
     | **Mean Absolute Percentage Error**
-    | **Symmetric Mean Absolute Percentage Error** 
-    | **Coefficient of Determination** 
-    | **Pearson Correlation Coefficient** 
+    | **Symmetric Mean Absolute Percentage Error**
+    | **Coefficient of Determination**
+    | **Pearson Correlation Coefficient**
     """
+
     def __init__(self):
         self["mae"] = mean_absolute_error
         self["mse"] = mean_squared_error
@@ -144,24 +162,28 @@ class RatingMetricSet(MetricSet):
         """
         return "RatingMetricSet()"
 
+
 class CoverageMetricSet(MetricSet):
     """
     A set of coverage metrics with the following metrics included:
-    
+
     """
+
     def __repr__(self):
         """
         A representation of the CoverageMetricSet object.
         """
         return "CoverageMetricSet()"
 
+
 class RankingMetricSet(MetricSet):
     """
     A set of ranking metrics with the following metrics included:
-    
+
     """
+
     def __repr__(self):
         """
         A representation of the RankingMetricSet object.
         """
-        return "RankingMetricSet()"
\ No newline at end of file
+        return "RankingMetricSet()"
