@@ -1,6 +1,8 @@
-import numpy as np
 from functools import wraps
 
+import numpy as np
+
+
 def binarize(metric):
     """
     Binarize the predictions for a ground-truth - prediction vector pair.
@@ -10,6 +12,7 @@ def binarize(metric):
     Returns:
         metric_wrapper (function): The function which wraps the metric and binarizes the probability scores.
     """
+
     @wraps(metric)
     def metric_wrapper(*args, **kwargs):
         # TODO: Move to optimal binning. Youden’s J statistic.
@@ -18,8 +21,10 @@ def binarize(metric):
         y_score[y_score >= 0.5] = 1
         score = metric(*args, **kwargs)
         return score
+
     return metric_wrapper
 
+
 def normalize(metric):
     """
     Normalize the predictions for a ground-truth - prediction vector pair.
@@ -29,14 +34,16 @@ def normalize(metric):
     Returns:
         metric_wrapper (function): The function which wraps the metric and normalizes predictions.
     """
+
     @wraps(metric)
-    def metric_wrapper(*args, **kwargs):  
+    def metric_wrapper(*args, **kwargs):
         y_true = args[0]
         y_score = args[1]
         y_mean = np.mean(y_true)
         y_std = np.std(y_true)
-        y_true = (y_true - y_mean)/y_std
-        y_score = (y_score - y_mean)/y_std
+        y_true[:] = (y_true - y_mean) / y_std
+        y_score[:] = (y_score - y_mean) / y_std
         score = metric(*args, **kwargs)
         return score
-    return metric_wrapper
\ No newline at end of file
+
+    return metric_wrapper
